@@ -68,11 +68,13 @@ DSD_Cubes <- function(k=2, d=2, center, size, p, noise = 0, noise_range) {
             p = p,
             noise = noise,
             noise_range = noise_range)
-  class(l) <- c("DSD_Cubes","DSD_R","DSD")
+  class(l) <- c("DSD_Cubes", "DSD_R", "DSD_data.frame", "DSD")
   l
 }
 
-get_points.DSD_Cubes <- function(x, n=1, assignment = FALSE, ...) {
+get_points.DSD_Cubes <- function(x, n=1, 
+  outofpoints=c("stop", "warn", "ignore"), 
+  cluster = FALSE, class = FALSE, ...) {
   
   clusterOrder <- sample(x=c(1:x$k), 
                          size=n, 
@@ -96,6 +98,8 @@ get_points.DSD_Cubes <- function(x, n=1, assignment = FALSE, ...) {
   }
   
   data <- as.data.frame(data)
-  if(assignment) attr(data, "assignment") <- clusterOrder
+  if(cluster) attr(data, "cluster") <- clusterOrder
+  if(class) data <- cbind(data, class = clusterOrder)
+  
   data
 }
