@@ -20,12 +20,17 @@
 DSD_UniformNoise <- function(d=2, range=NULL) {
   if(is.null(range)) range <- matrix(c(0,1), ncol=2, nrow=d, byrow=TRUE)
   structure(list(description = "Uniform Noise", d = d, range=range),
-	      class=c("DSD_UniformNoise","DSD_R","DSD"))
+	      class=c("DSD_UniformNoise", "DSD_R", "DSD_data.frame", "DSD"))
   }
   
-get_points.DSD_UniformNoise <- function(x, n=1, assignment = FALSE, ...) {
+get_points.DSD_UniformNoise <- function(x, n=1, 
+    cluster=FALSE, class=FALSE, ...) {
+    
     data <- as.data.frame(t(replicate(n, 
       runif(x$d, min=x$range[,1], max=x$range[,2]))))
-    if(assignment) attr(data, "assignment") <- rep(NA_integer_, n)
+    
+    if(cluster) attr(data, "cluster") <- rep(NA_integer_, n)
+    if(class) data <- cbind(data, class = rep(NA_integer_, n))
+    
     data
 }
